/*
 * GTX - GLib Test Extensions
 * Copyright (C) Canonical Ltd 2010
 * Author: mikkel.kamstrup@canonical.com
 *
 * GTX is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or (at your option) any later version.
 * 
 * GTX is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 * 
 * You should have received a copy of the GNU Lesser General Public
 * License along with GTX.  If not, write to:
 * 	The Free Software Foundation, Inc.,
 * 	51 Franklin Street, Fifth Floor
 * 	Boston, MA  02110-1301, USA.
 */

/*
 * This is a sample test case where a parent spawns and external command
 * and wait for it to exit while spinning a main loop.
 */

#include <gtx.h>

static gboolean
parent_print_hi (gpointer data)
{
  g_debug ("Parent process says hi!");
  return TRUE;
}

#define COMMAND_TIMEOUT 2000

int
main (gint argc, gchar *argv[])
{
  gchar **command;
  g_type_init ();

  command = g_new0(gchar*, 3);
  command[0] = "sleep"; command[1] = "1"; command[2] = NULL;
  
  /* When ever there's a main loop running the
   * parent process keep saying 'hi' */
  g_timeout_add (200, (GSourceFunc)parent_print_hi, NULL);
  
  /* Sleeping for 1s should be OK */
  if (gtx_wait_for_command (".", command, COMMAND_TIMEOUT))
    g_critical ("Command 'sleep 1' timed out");
  else
    g_debug ("Command exited in due time");

  /* Assert that child exited with status 0 */
  gtx_assert_last_command_status (0);

  /* Sleeping for 3s should cause a timeout */
  command[1] = "3";
  if (gtx_wait_for_command (".", command, COMMAND_TIMEOUT))
    g_debug ("Command 'sleep 3' timed out - as expected");
  else
    g_critical ("Command 'sleep 3' did not time out as expected!");

  /* Assert that child exited with status 0 */
  gtx_assert_last_command_status (0);
  
  g_debug ("All tests passed");
  
  return 0;
}